@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # 设置管理域名 & 上传域名
-PUT_URL = 'http://'
+PUT_URL = 'http://apitest_user.up0.v1.wcsapi.com'
 MGR_URL = 'http://'
 
 # 设置分片上传的块大小和片大小，单位均为字节
@@ -24,7 +24,7 @@ logging_folder = '/tmp/logger/'
 tmp_record_folder = '/tmp/sliceupload/'
 
 # 设置分片上传并发线程数
-Thread_num = 1
+Thread_num = 4
 
 class PutPolicy(object):
     
