@@ -6,7 +6,7 @@ from wcs.commons.config import logging_folder
 from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
-from wcs.commons.util import get_logger
+from wcs.commons.logme import debug, warning, error
 from wcs.commons.util import urlsafe_base64_encode, urlsafe_base64_decode
 
 class BucketManager(object):
@@ -14,7 +14,6 @@ class BucketManager(object):
     def __init__(self, auth):
         self.auth = auth
         self.mgr_host = MGR_URL
-        self.logger = get_logger(logging_folder, 'FileManager')
 
     def limit_check(self):
         n = 0
@@ -32,9 +31,9 @@ class BucketManager(object):
 
     def delete(self, bucket, key):
         url = self.make_delete_url(bucket, key)
-        self.logger.info('Start to post request of delete %s:%s', bucket, key)
+        debug('Start to post request of delete %s:%s' % (bucket, key))
         code, text = _post(url=url, headers=self.gernerate_headers(url))
-        self.logger.info('The return code is %d and text of delete request is: %s', code, text)
+        debug('The return code is %d and text of delete request is: %s' % (code, text))
         return code, text
 
     def make_filestat_url(self, bucket, key):
@@ -42,9 +41,9 @@ class BucketManager(object):
 
     def stat(self, bucket, key):
         url = self.make_filestat_url(bucket, key)
-        self.logger.info('Start to get the stat of %s:%s', bucket, key)
+        debug('Start to get the stat of %s:%s' % ( bucket, key))
         code, text = _get(url=url, headers=self.gernerate_headers(url))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d and text : %s' % (code, text))
         return code, text
  
     def make_list_url(self, param):
@@ -64,7 +63,7 @@ class BucketManager(object):
             if limit in self.limit_check():
                 options['limit'] = limit
             else:
-                self.logger.error('Invalid limit ! Please redefine limit')
+                error('Invalid limit ! Please redefine limit')
                 raise ValueError("Invalid limit")
         if prefix is not None:
             options['prefix'] = prefix
@@ -72,10 +71,10 @@ class BucketManager(object):
             options['mode'] = mode
         url = self.make_list_url(options)
         if options is not None:
-            self.logger.info('List options is %s', options)
-        self.logger.info('List bucket %s', bucket)
+            debug('List options is %s' % options)
+        debug('List bucket %s' % bucket)
         code, text = _get(url=url, data=options, headers=self.gernerate_headers(url))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d and text : %s' % (code, text))
         return code, text
 
     def params_parse(self, params):
@@ -94,9 +93,9 @@ class BucketManager(object):
 
     def move(self, srcbucket, srckey, dstbucket, dstkey):
         url = self.make_move_url(srcbucket, srckey, dstbucket, dstkey)
-        self.logger.info('Move object %s from %s to %s' % (srckey, srcbucket, dstbucket))
+        debug('Move object %s from %s to %s:%s' % (srckey, srcbucket, dstbucket, dstkey))
         code, text = _post(url=url, headers=self.gernerate_headers(url))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d and text : %s' % (code, text))
         return code, text
  
     def make_copy_url(self, srcbucket, srckey, dstbucket, dstkey):
@@ -107,9 +106,9 @@ class BucketManager(object):
 
     def copy(self, srcbucket, srckey, dstbucket, dstkey):
         url = self.make_copy_url(srcbucket, srckey, dstbucket, dstkey)
-        self.logger.info('Copy object %s from %s to %s' % (srckey, srcbucket, dstbucket))
+        debug('Copy object %s from %s to %s:%s' % (srckey, srcbucket, dstbucket, dstkey))
         code, text = _post(url=url, headers=self.gernerate_headers(url))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d and text : %s' % (code, text))
         return code, text
 
     def setdeadline(self, bucket, key, deadline):
@@ -120,9 +119,9 @@ class BucketManager(object):
         param['key'] = urlsafe_base64_encode(key) 
         param['deadline'] = deadline 
         body = self.params_parse(param)
-        self.logger.info('Set deadline of %s to %s' % (key, deadline))
+        debug('Set deadline of %s to %s' % (key, deadline))
         code, text = _post(url=url, data=body, headers=self.gernerate_headers(url, body))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d and text : %s' % (code, text))
         return code, text
 
 #    def decompress(self, bucket, key, fops, notifyurl=None, force=None, separate=None):
@@ -135,9 +134,9 @@ class BucketManager(object):
 #        if force is not None:
 #            data['force'] = force
 #        reqdata = self.params_parse(data)
-#        self.logger.info('Decompress object %s' % (key))
+#        logme.debug('Decompress object %s' % (key))
 #        code, text = _post(url=url, headers=self.gernerate_headers(url, body=reqdata))
-#        self.logger.info('The return code : %d and text : %s', code, text)
+#        logme.debug('The return code : %d and text : %s', code, text)
 #        return code, text
 
 #    def update_mirror(self, bucket, filelist):
@@ -148,8 +147,8 @@ class BucketManager(object):
 #            encodelist = '|'.join(encodelist)
 #        param = urlsafe_base64_encode('{0}:{1}'.format(bucket, encodelist))
 #        url = '{0}/prefetch/{1}'.format(self.mgr_host, param)
-#        self.logger.info('Update mirror to bucket: %s' % (bucket))
+#        logme.debug('Update mirror to bucket: %s' % (bucket))
 #        code, text = _post(url=url, headers=self.gernerate_headers(url))
-#        self.logger.info('The return code : %d and text : %s', code, text)
+#        logme.debug('The return code : %d and text : %s', code, text)
 #        return code, text
        
