@@ -6,15 +6,14 @@ from wcs.commons.config import logging_folder
 from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
-from wcs.commons.util import get_logger
 from wcs.commons.util import urlsafe_base64_encode
+from wcs.commons.logme import debug, warning, error
 
 class Fmgr(object):
 
     def __init__(self, auth):
         self.auth = auth
         self.host = MGR_URL
-        self.logger = get_logger(logging_folder, 'Fmgr')
 
     def gernerate_headers(self,url,body=None):
         token = self.auth.managertoken(url,body=body)
@@ -37,10 +36,10 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('Fmgr_move request body is: %s', reqdata)
-        self.logger.info('Start to move file')
+        debug('Fmgr_move request body is: %s' % reqdata)
+        debug('Start to move file')
         code, text = _post(url=url, data=reqdata, headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d ,text : %s' % (code, text))
         return code, text 
 
     def fmgr_copy(self, fops, notifyurl=None, separate=None):
@@ -51,10 +50,10 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('Fmgr_copy request body is: %s', reqdata)
-        self.logger.info('Start to copy file')
+        debug('Fmgr_copy request body is: %s' % reqdata)
+        debug('Start to copy file')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and persistentId/test : %s', code, text)
+        debug('The return code : %d, persistentId/test : %s' % (code, text))
         return code,text 
    
     def fmgr_fetch(self, fops, notifyurl=None, force=None, separate=None):
@@ -67,10 +66,10 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('fmgr_fetch request body is: %s', reqdata)
-        self.logger.info('Start to fetch file')
+        debug('fmgr_fetch request body is: %s' % (reqdata))
+        debug('Start to fetch file')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and persistentId/text : %s', code, text)
+        debug('The return code : %d, ersistentId/text : %s' % (code, text))
         return code,text
 
     def fmgr_delete(self, fops, notifyurl=None, separate=None):
@@ -81,10 +80,10 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('Fmgr_delete request body is: %s', reqdata)
-        self.logger.info('Start to superdelete operation')
+        debug('Fmgr_delete request body is: %s' % reqdata)
+        debug('Start to superdelete operation')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and persistentId/text : %s', code, text)
+        debug('The return code : %d, persistentId/text : %s' % (code, text))
         return code,text
 
     def prefix_delete(self, fops, notifyurl=None, separate=None):
@@ -95,10 +94,10 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('DeletePrefix request body is: %s', reqdata)
-        self.logger.info('Start to deletePrefix operation')
+        debug('DeletePrefix request body is: %s' % reqdata)
+        debug('Start to deletePrefix operation')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and persistentId/text : %s', code, text)
+        debug('The return code : %d, persistentId/text : %s' % (code, text))
         return code,text
 
     def m3u8_delete(self, fops, notifyurl=None, separate=None):
@@ -109,15 +108,15 @@ class Fmgr(object):
         if separate is not None:
             data['separate'] = separate
         reqdata = self.params_parse(data)
-        self.logger.info('Deletem3u8 request body is: %s', reqdata)
-        self.logger.info('Start to deletem3u8 operation')
+        debug('Deletem3u8 request body is: %s' % reqdata)
+        debug('Start to deletem3u8 operation')
         code, text = _post(url=url, data=reqdata,headers=self.gernerate_headers(url, body=reqdata))
-        self.logger.info('The return code : %d and persistentId/text : %s', code, text)
+        debug('The return code : %d, persistentId/text : %s' % (code, text))
         return code,text
    
     def status(self, persistentId):
         url = '{0}/fmgr/status?persistentId={1}'.format(self.host, persistentId)
-        self.logger.info('Start to get status of persistentId: %s', persistentId)
+        debug('Start to get status of persistentId: %s' % persistentId)
         code, text = _get(url=url)
-        self.logger.info('The return code : %d and text : %s', code, text)
+        debug('The return code : %d, text : %s' % (code, text))
         return code, text
