@@ -6,8 +6,8 @@ from wcs.commons.config import logging_folder
 from wcs.commons.http import _post
 from wcs.commons.http import _get
 from wcs.commons.util import entry
-from wcs.commons.util import get_logger
 from wcs.commons.util import urlsafe_base64_encode
+from wcs.commons.logme import debug, warning, error
 
 class PersistentFop(object):
 
@@ -15,7 +15,6 @@ class PersistentFop(object):
         self.bucket = bucket
         self.host = MGR_URL
         self.auth = auth
-        self.logger = get_logger(logging_folder, 'persistentfop')
       
     def build_op(self,cmd, first_arg, **kwargs):
         op = [cmd]
@@ -40,9 +39,9 @@ class PersistentFop(object):
 
     def fops_status(self, persistentId):
         url = '{0}/status/get/prefop?persistentId={1}'.format(self.host, persistentId)
-        self.logger.info('Start to get status of persistentId: %s', persistentId)
+        debug('Start to get status of persistentId: %s' % persistentId)
         code, text = _get(url=url)
-        self.logger.info('The return code and text of status request is:%d %s', code, text)
+        debug('The return code and text of status request is:%d %s' % (code, text))
         return code, text
 
     def params(self,params):
@@ -69,10 +68,10 @@ class PersistentFop(object):
             data['separate'] = 1
         url = '{0}/fops'.format(self.host)
         headers,reqdata = self.headers(url,data)
-        self.logger.info('PersistentFops is %s', fops)
-        self.logger.info('Start to post persistentFops')
+        debug('PersistentFops is %s' % fops)
+        debug('Start to post persistentFops')
         code,text = _post(url=url, data=reqdata,headers=headers)
-        self.logger.info('The return code and text of persistentfops is:%d %s', code, text)
+        debug('Code: %d, text: %s' % (code, text))
         return code,text
 
 
