@@ -156,7 +156,7 @@ class SliceUpload(object):
             return self.make_file(PUT_URL, self.blockStatus(results), uploadBatch)
         else:
             fail_list = self.result_analysis(results)
-            debug('Sorry, These block %s upload fail',fail_list )
+            debug('Sorry, These block %s upload fail' % (fail_list ))
             return -1, "slice upload fail" 
 
     def make_bput_post(self, ctx, bputnum, uploadBatch, bput_next):
@@ -189,6 +189,7 @@ class SliceUpload(object):
         blkretry = mkblk_retries
         blkcode, blktext = _post(url=url, headers=headers, data=bput)
         while blkretry and self.need_retry(blkcode):
+            debug('url: %s' % (url ))
             blkcode, blktext = _post(url=url, headers=headers, data=bput)
             blkretry = blkretry - 1
         if self.need_retry(blkcode) or blkcode != 200:
